@@ -147,6 +147,10 @@ const Application = new Lang.Class({
     },
 
     _refreshMinerNow: function(miner) {
+        let env = GLib.getenv('DOCUMENTS_DISABLE_MINERS');
+        if (env)
+            return false;
+
         miner.RefreshDBRemote(DBus.CALL_FLAG_START, Lang.bind(this,
             function(res, error) {
                 if (error) {
@@ -156,7 +160,7 @@ const Application = new Lang.Class({
 
                 Mainloop.timeout_add_seconds(MINER_REFRESH_TIMEOUT,
                                              Lang.bind(this, function() {
-                                                 this._refreshMinerNow(miner)
+                                                 this._refreshMinerNow(miner);
                                              }));
             }));
 
