@@ -25,6 +25,7 @@
 
 #include "gd-gdata-goa-authorizer.h"
 #include "gd-gdata-miner.h"
+#include "gd-miner-tracker.h"
 #include "gd-utils.h"
 
 #define MINER_IDENTIFIER "gd:gdata:miner:86ec9bc9-c242-427f-aa19-77b5a2c9b6f0"
@@ -43,12 +44,6 @@ struct _GdGDataMinerPrivate {
   GList *pending_jobs;
 };
 
-static gchar *
-_tracker_utils_format_into_graph (const gchar *graph)
-{
-  return (graph != NULL) ? g_strdup_printf ("INTO <%s> ", graph) : g_strdup ("");
-}
-
 static gboolean
 _tracker_sparql_connection_toggle_favorite (TrackerSparqlConnection *connection,
                                             GCancellable *cancellable,
@@ -85,82 +80,6 @@ _tracker_sparql_connection_toggle_favorite (TrackerSparqlConnection *connection,
   return retval;
 }
 
-static gboolean
-_tracker_sparql_connection_insert_or_replace_triple (TrackerSparqlConnection *connection,
-                                                     GCancellable *cancellable,
-                                                     GError **error,
-                                                     const gchar *graph,
-                                                     const gchar *resource,
-                                                     const gchar *property_name,
-                                                     const gchar *property_value)
-{
-  GString *insert;
-  gchar *graph_str;
-  gboolean retval = TRUE;
-
-  graph_str = _tracker_utils_format_into_graph (graph);
-
-  insert = g_string_new (NULL);
-  g_string_append_printf 
-    (insert,
-     "INSERT OR REPLACE %s { <%s> a nie:InformationElement ; %s \"%s\" }",
-     graph_str, resource, property_name, property_value);
-
-  g_debug ("Insert or replace triple: query %s", insert->str);
-
-  tracker_sparql_connection_update (connection, insert->str, 
-                                    G_PRIORITY_DEFAULT, cancellable,
-                                    error);
-
-  g_string_free (insert, TRUE);
-
-  if (*error != NULL)
-    retval = FALSE;
-
-  g_free (graph_str);
-
-  return retval;
-}
-
-static gboolean
-_tracker_sparql_connection_set_triple (TrackerSparqlConnection *connection,
-                                       GCancellable *cancellable,
-                                       GError **error,
-                                       const gchar *graph,
-                                       const gchar *resource,
-                                       const gchar *property_name,
-                                       const gchar *property_value)
-{
-  GString *delete;
-  gboolean retval = TRUE;
-
-  delete = g_string_new (NULL);
-  g_string_append_printf 
-    (delete,
-     "DELETE { <%s> %s ?val } WHERE { <%s> %s ?val }", resource,
-     property_name, resource, property_name);
-
-  tracker_sparql_connection_update (connection, delete->str, 
-                                    G_PRIORITY_DEFAULT, cancellable,
-                                    error);
-
-  g_string_free (delete, TRUE);
-  if (*error != NULL)
-    {
-      retval = FALSE;
-      goto out;
-    }
-
-  retval = 
-    _tracker_sparql_connection_insert_or_replace_triple (connection, 
-                                                         cancellable, error,
-                                                         graph, resource,
-                                                         property_name, property_value);
-
- out:
-  return retval;
-}
-
 static gchar*
 _tracker_utils_ensure_contact_resource (TrackerSparqlConnection *connection,
                                         GCancellable *cancellable,
@@ -251,107 +170,6 @@ _tracker_utils_ensure_contact_resource (TrackerSparqlConnection *connection,
   return retval;
 }
 
-static gchar*
-_tracker_sparql_connection_ensure_resource (TrackerSparqlConnection *connection,
-                                            GCancellable *cancellable,
-                                            GError **error,
-                                            const gchar *graph,
-                                            const gchar *identifier,
-                                            const gchar *class,
-                                            ...)
-{
-  GString *select, *insert, *inner;
-  va_list args;
-  const gchar *arg;
-  TrackerSparqlCursor *cursor;
-  gboolean res;
-  gchar *retval = NULL;
-  gchar *graph_str;
-  GVariant *insert_res;
-  GVariantIter *iter;
-  gchar *key = NULL, *val = NULL;
-
-  /* build the inner query with all the classes */
-  va_start (args, class);
-  inner = g_string_new (NULL);
-
-  for (arg = class; arg != NULL; arg = va_arg (args, const gchar *))
-    g_string_append_printf (inner, " a %s; ", arg);
-
-  g_string_append_printf (inner, "nao:identifier \"%s\"", identifier);
-
-  va_end (args);
-
-  /* query if such a resource is already in the DB */
-  select = g_string_new (NULL);
-  g_string_append_printf (select, 
-                          "SELECT ?urn WHERE { ?urn %s }", inner->str);
-
-  cursor = tracker_sparql_connection_query (connection,
-                                            select->str,
-                                            cancellable, error);
-
-  g_string_free (select, TRUE);
-
-  if (*error != NULL)
-    goto out;
-
-  res = tracker_sparql_cursor_next (cursor, cancellable, error);
-
-  if (*error != NULL)
-    goto out;
-
-  if (res)
-    {
-      /* return the found resource */
-      retval = g_strdup (tracker_sparql_cursor_get_string (cursor, 0, NULL));
-      g_debug ("Found resource in the store: %s", retval);
-      goto out;
-    }
-
-  /* not found, create the resource */
-  insert = g_string_new (NULL);
-  graph_str = _tracker_utils_format_into_graph (graph);
-
-  g_string_append_printf (insert, "INSERT %s { _:res %s }", 
-                          graph_str, inner->str);
-  g_free (graph_str);
-  g_string_free (inner, TRUE);
-
-  insert_res = 
-    tracker_sparql_connection_update_blank (connection, insert->str,
-                                            G_PRIORITY_DEFAULT, NULL, error);
-
-  g_string_free (insert, TRUE);
-
-  if (*error != NULL)
-    goto out;
-
-  /* the result is an "aaa{ss}" variant */
-  g_variant_get (insert_res, "aaa{ss}", &iter);
-  g_variant_iter_next (iter, "aa{ss}", &iter);
-  g_variant_iter_next (iter, "a{ss}", &iter);
-  g_variant_iter_next (iter, "{ss}", &key, &val);
-
-  g_variant_iter_free (iter);
-  g_variant_unref (insert_res);
-
-  if (g_strcmp0 (key, "res") == 0)
-    {
-      retval = val;
-    }
-  else
-    {
-      g_free (val);
-      goto out;
-    }
-
-  g_debug ("Created a new resource: %s", retval);
-
- out:
-  g_clear_object (&cursor);
-  return retval;
-}
 
 typedef struct {
   GdGDataMiner *self;
@@ -517,7 +335,7 @@ account_miner_job_process_entry (AccountMinerJob *job,
   else if (GDATA_IS_DOCUMENTS_FOLDER (doc_entry))
     class = "nfo:DataContainer";
  
-  resource = _tracker_sparql_connection_ensure_resource
+  resource = gd_miner_tracker_sparql_connection_ensure_resource
     (job->connection, 
      job->cancellable, error,
      resource_url, identifier,
@@ -528,7 +346,7 @@ account_miner_job_process_entry (AccountMinerJob *job,
 
   datasource_urn = g_strdup_printf ("gd:goa-account:%s", 
                                     goa_account_get_id (job->account));
-  _tracker_sparql_connection_set_triple 
+  gd_miner_tracker_sparql_connection_set_triple
     (job->connection, job->cancellable, error,
      identifier, resource,
      "nie:dataSource", datasource_urn);
@@ -541,7 +359,7 @@ account_miner_job_process_entry (AccountMinerJob *job,
   alternate = gdata_entry_look_up_link (entry, GDATA_LINK_ALTERNATE);
   alternate_uri = gdata_link_get_uri (alternate);
 
-  _tracker_sparql_connection_insert_or_replace_triple
+  gd_miner_tracker_sparql_connection_insert_or_replace_triple
     (job->connection, 
      job->cancellable, error,
      identifier, resource,
@@ -559,7 +377,7 @@ account_miner_job_process_entry (AccountMinerJob *job,
       parent_resource_id = 
         g_strdup_printf ("gd:collection:%s", gdata_link_get_uri (parent));
 
-      parent_resource_urn = _tracker_sparql_connection_ensure_resource
+      parent_resource_urn = gd_miner_tracker_sparql_connection_ensure_resource
         (job->connection, job->cancellable, error,
          NULL, parent_resource_id,
          "nfo:RemoteDataObject", "nfo:DataContainer", NULL);
@@ -568,7 +386,7 @@ account_miner_job_process_entry (AccountMinerJob *job,
       if (*error != NULL)
         goto out;
 
-      _tracker_sparql_connection_insert_or_replace_triple
+      gd_miner_tracker_sparql_connection_insert_or_replace_triple
         (job->connection,
          job->cancellable, error,
          identifier, resource,
@@ -598,7 +416,7 @@ account_miner_job_process_entry (AccountMinerJob *job,
   if (*error != NULL)
     goto out;
 
-  _tracker_sparql_connection_insert_or_replace_triple
+  gd_miner_tracker_sparql_connection_insert_or_replace_triple
     (job->connection, 
      job->cancellable, error,
      identifier, resource,
@@ -607,7 +425,7 @@ account_miner_job_process_entry (AccountMinerJob *job,
   if (*error != NULL)
     goto out;
 
-  _tracker_sparql_connection_insert_or_replace_triple
+  gd_miner_tracker_sparql_connection_insert_or_replace_triple
     (job->connection, 
      job->cancellable, error,
      identifier, resource,
@@ -631,7 +449,7 @@ account_miner_job_process_entry (AccountMinerJob *job,
       if (*error != NULL)
         goto out;
 
-      _tracker_sparql_connection_insert_or_replace_triple
+      gd_miner_tracker_sparql_connection_insert_or_replace_triple
         (job->connection, 
          job->cancellable, error,
          identifier, resource,
@@ -673,7 +491,7 @@ account_miner_job_process_entry (AccountMinerJob *job,
                                                                  scope_value,
                                                                  "");
 
-      _tracker_sparql_connection_insert_or_replace_triple
+      gd_miner_tracker_sparql_connection_insert_or_replace_triple
         (job->connection,
          job->cancellable, error,
          identifier, resource,
@@ -686,7 +504,7 @@ account_miner_job_process_entry (AccountMinerJob *job,
     }
 
   date = gd_iso8601_from_timestamp (gdata_entry_get_published (entry));
-  _tracker_sparql_connection_insert_or_replace_triple
+  gd_miner_tracker_sparql_connection_insert_or_replace_triple
     (job->connection, 
      job->cancellable, error,
      identifier, resource,
@@ -697,7 +515,7 @@ account_miner_job_process_entry (AccountMinerJob *job,
     goto out;
 
   date = gd_iso8601_from_timestamp (gdata_entry_get_updated (entry));
-  _tracker_sparql_connection_insert_or_replace_triple
+  gd_miner_tracker_sparql_connection_insert_or_replace_triple
     (job->connection, 
      job->cancellable, error,
      identifier, resource,
