@@ -113,11 +113,16 @@ const SearchType = new Lang.Class({
     _init: function(params) {
         this.id = params.id;
         this.name = params.name;
-        this._filter = (params.filter) ? (params.filter) : '';
+        this._filter = (params.filter) ? (params.filter) : '(true)';
+        this._where = (params.where) ? (params.where) : '';
     },
 
     getFilter: function() {
         return this._filter;
+    },
+
+    getWhere: function() {
+        return this._where;
     }
 });
 
@@ -132,22 +137,43 @@ const SearchTypeManager = new Lang.Class({
                                       name: _("All") }));
         this.addItem(new SearchType({ id: 'collections',
                                       name: _("Collections"),
-                                      filter: '((fn:contains(rdf:type(?urn), \"nfo#DataContainer\")) && '
-                                              + '(fn:starts-with(nao:identifier(?urn), \"gd:collection\")))' }));
+                                      filter: 'fn:starts-with(nao:identifier(?urn), \"gd:collection\")',
+                                      where: '?urn rdf:type nfo:DataContainer .' }));
         this.addItem(new SearchType({ id: 'pdf',
                                       name: _("PDF Documents"),
-                                      filter: 'fn:contains(nie:mimeType(?urn), \"application/pdf\")' }));
+                                      filter: 'fn:contains(nie:mimeType(?urn), \"application/pdf\")',
+                                      where: '?urn rdf:type nfo:PaginatedTextDocument .' }));
         this.addItem(new SearchType({ id: 'presentations',
                                       name: _("Presentations"),
-                                      filter: 'fn:contains(rdf:type(?urn), \"nfo#Presentation\")' }));
+                                      where: '?urn rdf:type nfo:Presentation .' }));
         this.addItem(new SearchType({ id: 'spreadsheets',
                                       name: _("Spreadsheets"),
-                                      filter: 'fn:contains(rdf:type(?urn), \"nfo#Spreadsheet\")'}));
+                                      where: '?urn rdf:type nfo:Spreadsheet .' }));
         this.addItem(new SearchType({ id: 'textdocs',
                                       name: _("Text Documents"),
-                                      filter: 'fn:contains(rdf:type(?urn), \"nfo#PaginatedTextDocument\")' }));
+                                      where: '?urn rdf:type nfo:PaginatedTextDocument .' }));
 
         this.setActiveItemById('all');
+    },
+
+    getCurrentTypes: function() {
+        let activeItem = this.getActiveItem();
+
+        if (activeItem.id == 'all')
+            return this.getAllTypes();
+
+        return [ activeItem ];
+    },
+
+    getAllTypes: function() {
+        let types = [];
+
+        this.forEachItem(function(item) {
+            if (item.id != 'all')
+                types.push(item);
+            });
+
+        return types;
     }
 });
 
@@ -345,9 +371,6 @@ const Searchbar = new Lang.Class({
                                             height: 0 });
 
         this._searchEntry = new Gd.TaggedEntry({ width_request: 260,
-                                                 secondary_icon_name: 'edit-find-symbolic',
-                                                 secondary_icon_sensitive: false,
-                                                 secondary_icon_activatable: false,
                                                  no_show_all: true,
                                                  hexpand: true });
         this._searchEntry.connect('tag-clicked',
@@ -403,17 +426,6 @@ const Searchbar = new Lang.Class({
             }));
 
         this._searchEntry.connect('changed', Lang.bind(this, function() {
-            let text = this._searchEntry.get_text();
-            if (text && text != '') {
-                this._searchEntry.secondary_icon_name = 'edit-clear-symbolic';
-                this._searchEntry.secondary_icon_sensitive = true;
-                this._searchEntry.secondary_icon_activatable = true;
-            } else {
-                this._searchEntry.secondary_icon_name = 'edit-find-symbolic';
-                this._searchEntry.secondary_icon_sensitive = false;
-                this._searchEntry.secondary_icon_activatable = false;
-            }
-
             if (this._searchEntryTimeout != 0) {
                 Mainloop.source_remove(this._searchEntryTimeout);
                 this._searchEntryTimeout = 0;
@@ -428,10 +440,6 @@ const Searchbar = new Lang.Class({
             }));
         }));
 
-        this._searchEntry.connect('icon-release', Lang.bind(this, function() {
-            this._searchEntry.set_text('');
-        }));
-
         this.widget.insert(item, 0);
         this._searchEntry.set_text(Global.searchController.getString());
 
