@@ -113,11 +113,9 @@ function _createGIcon(cursor) {
     return gicon;
 }
 
-function CreateCollectionIconJob(id) {
-    this._init(id);
-}
+const CreateCollectionIconJob = new Lang.Class({
+    Name: 'CreateCollectionIconJob',
 
-CreateCollectionIconJob.prototype = {
     _init: function(id) {
         this._id = id;
         this._itemIcons = [];
@@ -225,13 +223,11 @@ CreateCollectionIconJob.prototype = {
     _returnPixbuf: function() {
         this._callback(Gd.create_collection_icon(_SHELL_SEARCH_ICON_SIZE, this._itemIcons));
     }
-};
+});
 
-function FetchMetasJob(ids) {
-    this._init(ids);
-}
+const FetchMetasJob = new Lang.Class({
+    Name: 'FetchMetasJob',
 
-FetchMetasJob.prototype = {
     _init: function(ids) {
         this._ids = ids;
         this._metas = [];
@@ -295,30 +291,29 @@ FetchMetasJob.prototype = {
                     }));
             }));
     }
-};
+});
 
-function FetchIdsJob(terms) {
-    this._init(terms);
-}
+const FetchIdsJob = new Lang.Class({
+    Name: 'FetchIdsJob',
 
-FetchIdsJob.prototype = {
     _init: function(terms) {
         this._terms = terms;
         this._ids = [];
     },
 
-    run: function(callback) {
+    run: function(callback, cancellable) {
         this._callback = callback;
+        this._cancellable = cancellable;
         Global.searchController.setString(this._terms.join(' ').toLowerCase());
 
         let query = Global.queryBuilder.buildGlobalQuery();
-        Global.connectionQueue.add(query.sparql, null, Lang.bind(this,
+        Global.connectionQueue.add(query.sparql, this._cancellable, Lang.bind(this,
             function(object, res) {
                 let cursor = null;
 
                 try {
                     cursor = object.query_finish(res);
-                    cursor.next_async(null, Lang.bind(this, this._onCursorNext));
+                    cursor.next_async(this._cancellable, Lang.bind(this, this._onCursorNext));
                 } catch (e) {
                     log('Error querying tracker: ' + e);
                     callback(this._ids);
@@ -340,19 +335,17 @@ FetchIdsJob.prototype = {
 
         if (valid) {
             this._ids.push(cursor.get_string(Query.QueryColumns.URN)[0]);
-            cursor.next_async(null, Lang.bind(this, this._onCursorNext));
+            cursor.next_async(this._cancellable, Lang.bind(this, this._onCursorNext));
         } else {
             cursor.close();
             this._callback(this._ids);
         }
     }
-};
+});
 
-function ShellSearchProvider() {
-    this._init();
-}
+const ShellSearchProvider = new Lang.Class({
+    Name: 'ShellSearchProvider',
 
-ShellSearchProvider.prototype = {
     _init: function() {
         Gio.DBus.own_name(Gio.BusType.SESSION,
                           SEARCH_PROVIDER_NAME,
@@ -365,6 +358,7 @@ ShellSearchProvider.prototype = {
         this._initReal();
 
         this._timeoutId = 0;
+        this._cancellable = new Gio.Cancellable();
     },
 
     _onBusAcquired: function() {
@@ -447,22 +441,28 @@ ShellSearchProvider.prototype = {
         let terms = params[0];
         this._resetTimeout();
 
+        this._cancellable.cancel();
+        this._cancellable.reset();
+
         let job = new FetchIdsJob(terms);
         job.run(Lang.bind(this,
             function(ids) {
                 invocation.return_value(GLib.Variant.new('(as)', [ ids ]));
-            }));
+            }), this._cancellable);
     },
 
     GetSubsearchResultSetAsync: function(params, invocation) {
         let [previousResults, terms] = params;
         this._resetTimeout();
 
+        this._cancellable.cancel();
+        this._cancellable.reset();
+
         let job = new FetchIdsJob(terms);
         job.run(Lang.bind(this,
             function(ids) {
                 invocation.return_value(GLib.Variant.new('(as)', [ ids ]));
-            }));
+            }), this._cancellable);
     },
 
     GetResultMetasAsync: function(params, invocation) {
@@ -511,7 +511,7 @@ ShellSearchProvider.prototype = {
     run: function() {
         Mainloop.run(MAINLOOP_ID);
     }
-};
+});
 
 function start() {
     let searchProvider = new ShellSearchProvider();
