@@ -35,11 +35,9 @@ const QueryType = {
     UPDATE_BLANK: 2
 };
 
-function TrackerConnectionQueue() {
-    this._init();
-}
+const TrackerConnectionQueue = new Lang.Class({
+    Name: 'TrackerConnectionQueue',
 
-TrackerConnectionQueue.prototype = {
     _init: function() {
         this._queue = [];
         this._running = false;
@@ -101,18 +99,16 @@ TrackerConnectionQueue.prototype = {
         this._running = false;
         this._checkQueue();
     }
-};
+});
 
 const RefreshFlags = {
     NONE: 0,
     RESET_OFFSET: 1 << 0
 };
 
-function TrackerController() {
-    this._init();
-}
+const TrackerController = new Lang.Class({
+    Name: 'TrackerController',
 
-TrackerController.prototype = {
     _init: function() {
         this._currentQuery = null;
         this._cancellable = new Gio.Cancellable();
@@ -124,27 +120,18 @@ TrackerController.prototype = {
         // useful for debugging
         this._lastQueryTime = 0;
 
-        this._sourceManager = Global.sourceManager;
-        this._sourceManager.connect('item-added', Lang.bind(this, this._onSourceAddedRemoved));
-        this._sourceManager.connect('item-removed', Lang.bind(this, this._onSourceAddedRemoved));
-        this._sourceManager.connect('active-changed',
-                                    Lang.bind(this, this._refreshForObject));
+        Global.sourceManager.connect('item-added', Lang.bind(this, this._onSourceAddedRemoved));
+        Global.sourceManager.connect('item-removed', Lang.bind(this, this._onSourceAddedRemoved));
+        Global.sourceManager.connect('active-changed', Lang.bind(this, this._refreshForObject));
 
-        this._offsetController = Global.offsetController;
-        this._offsetController.connect('offset-changed',
-                                       Lang.bind(this, this._performCurrentQuery));
+        Global.offsetController.connect('offset-changed', Lang.bind(this, this._performCurrentQuery));
 
-        Global.collectionManager.connect('active-changed',
-                                         Lang.bind(this, this._refreshForObject));
-        Global.searchController.connect('search-string-changed',
-                                        Lang.bind(this, this._refreshForObject));
-        Global.searchCategoryManager.connect('active-changed',
-                                             Lang.bind(this, this._refreshForObject));
-        Global.searchTypeManager.connect('active-changed',
-                                         Lang.bind(this, this._refreshForObject));
+        Global.collectionManager.connect('active-changed', Lang.bind(this, this._refreshForObject));
+        Global.searchController.connect('search-string-changed', Lang.bind(this, this._refreshForObject));
+        Global.searchCategoryManager.connect('active-changed', Lang.bind(this, this._refreshForObject));
+        Global.searchTypeManager.connect('active-changed', Lang.bind(this, this._refreshForObject));
 
-        Global.searchMatchManager.connect('active-changed',
-                                          Lang.bind(this, this._onSearchMatchChanged));
+        Global.searchMatchManager.connect('active-changed', Lang.bind(this, this._onSearchMatchChanged));
     },
 
     _setQueryStatus: function(status) {
@@ -173,7 +160,7 @@ TrackerController.prototype = {
         if (exception)
             Global.errorHandler.addQueryError(exception);
         else
-            this._offsetController.resetItemCount();
+            Global.offsetController.resetItemCount();
 
         if (this._queryQueued) {
             this._queryQueued = false;
@@ -270,5 +257,5 @@ TrackerController.prototype = {
 
         this._refreshInternal(RefreshFlags.NONE);
     }
-};
+});
 Signals.addSignalMethods(TrackerController.prototype);
